@@ -1,11 +1,21 @@
 from findpeaks.findpeaks import findpeaks
 
-from findpeaks.utils.smoothline import smooth_line1d, smooth_line2d
-import findpeaks.utils.compute as compute
+from findpeaks.utils.smoothline import interpolate_line1d, interpolate_line2d
+import findpeaks.utils.stats as stats
+
+# Import the denosing filters
+from findpeaks.filters.lee import lee_filter
+from findpeaks.filters.lee_enhanced import lee_enhanced_filter
+from findpeaks.filters.kuan import kuan_filter
+from findpeaks.filters.frost import frost_filter
+from findpeaks.filters.median import median_filter
+from findpeaks.filters.mean import mean_filter
+
+
 
 __author__ = 'Erdogan Tasksen'
 __email__ = 'erdogant@gmail.com'
-__version__ = '1.0.2'
+__version__ = '2.0.0'
 
 # module level doc-string
 __doc__ = """
@@ -23,7 +33,7 @@ Examples
 --------
 >>> from findpeaks import findpeaks
 >>> X = [9,60,377,985,1153,672,501,1068,1110,574,135,23,3,47,252,812,1182,741,263,33]
->>> fp = findpeaks(smooth=10, lookahead=1)
+>>> fp = findpeaks(interpolate=10, lookahead=1)
 >>> results = fp.fit(X)
 >>> fp.plot()
 >>>
@@ -35,7 +45,7 @@ Examples
 >>>
 >>> # Image example
 >>> from findpeaks import findpeaks
->>> fp = findpeaks(denoise=30, resize=(300,300))
+>>> fp = findpeaks(denoise='fastnl', h=30, resize=(300,300))
 >>> X = fp.import_example('2dpeaks_image')
 >>> results = fp.fit(X)
 >>> fp.plot()
